==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The ARC autoprovisioning configuration
 * @property configuration Configuration for servers Arc auto provisioning
 * @property enabled Is arc auto provisioning enabled
 */
public data class DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs(
    public val configuration: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>? = null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs =
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.builder()
            .configuration(configuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs].
 */
@PulumiTagMarker
public class DefenderForDatabasesGcpOfferingArcAutoProvisioningArgsBuilder internal constructor() {
    private var configuration: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value Configuration for servers Arc auto provisioning
     */
    @JvmName("rspcsnbawtgjdrmx")
    public suspend
    fun configuration(`value`: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>) {
        this.configuration = value
    }

    /**
     * @param value Is arc auto provisioning enabled
     */
    @JvmName("ghddgratjjcdbolt")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Configuration for servers Arc auto provisioning
     */
    @JvmName("wfuwkiwhdbmupnxs")
    public suspend fun configuration(`value`: DefenderForDatabasesGcpOfferingConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configuration = mapped
    }

    /**
     * @param argument Configuration for servers Arc auto provisioning
     */
    @JvmName("iwqrxoflowqtdsqv")
    public suspend
    fun configuration(argument: suspend DefenderForDatabasesGcpOfferingConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = DefenderForDatabasesGcpOfferingConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.configuration = mapped
    }

    /**
     * @param value Is arc auto provisioning enabled
     */
    @JvmName("ngvmtaqwakqbuwhf")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs =
        DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs(
            configuration = configuration,
            enabled = enabled,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The ARC autoprovisioning configuration
 * @property configuration Configuration for servers Arc auto provisioning
 * @property enabled Is arc auto provisioning enabled
 */
public data class DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs(
    public val configuration: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>? = null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs =
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs.builder()
            .configuration(configuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs].
 */
@PulumiTagMarker
public class DefenderForDatabasesGcpOfferingArcAutoProvisioningArgsBuilder internal constructor() {
    private var configuration: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value Configuration for servers Arc auto provisioning
     */
    @JvmName("neixayqvrtftiypd")
    public suspend
    fun configuration(`value`: Output<DefenderForDatabasesGcpOfferingConfigurationArgs>) {
        this.configuration = value
    }

    /**
     * @param value Is arc auto provisioning enabled
     */
    @JvmName("rjvwrqdmptsxemqb")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Configuration for servers Arc auto provisioning
     */
    @JvmName("viunaxdfkelqkodi")
    public suspend fun configuration(`value`: DefenderForDatabasesGcpOfferingConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configuration = mapped
    }

    /**
     * @param argument Configuration for servers Arc auto provisioning
     */
    @JvmName("fghpjtkhnxmrifoh")
    public suspend
    fun configuration(argument: suspend DefenderForDatabasesGcpOfferingConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = DefenderForDatabasesGcpOfferingConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.configuration = mapped
    }

    /**
     * @param value Is arc auto provisioning enabled
     */
    @JvmName("eodpwxoeqamrkymq")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs =
        DefenderForDatabasesGcpOfferingArcAutoProvisioningArgs(
            configuration = configuration,
            enabled = enabled,
        )
}
